@@ -24,7 +24,7 @@ class TestCasePath:
     @property
     def full_test_case_path(self) -> Path:
         project_root: Path = Path(self._project_root).absolute()
-        full_test_case_path: Path = (project_root / self._test_case)
+        full_test_case_path: Path = project_root / self._test_case
         return full_test_case_path
 
     @property
@@ -193,10 +193,10 @@ class TestCase(NamedTuple):
         wait_time_between_test_types: float = 3.0,
     ) -> "TestCase":
         """
-        This TestCase generator expects the test_case to be a fragment from the
-         project root to the test script. The project_root is prepended to the
-         test_case and provided as the TestCase.full_test_case_path'
-         value. That path is checked to ensure that a file by that
+        This TestCase generator expects the test_case_path to be a path fragment from the project
+         root to the test script. The project_root is prepended to the test_case and provided as
+         the TestCase.full_test_case_path'  value. That path is checked to ensure that a file by
+         that
          'full_test_case_path' exits.
 
         :param test_case_path:
@@ -204,12 +204,11 @@ class TestCase(NamedTuple):
         :param pytest_filter: pytest -k string
         :param test_types: for exceptional situations, limit a TestCase to
          run for limited set of TestType's
-        :param wait_between_test_types: when there are multiple tests types (pytest'ing), wait until each type is
-         done prior to running the next type
+        :param wait_between_test_types: when there are multiple tests types (pytest'ing),
+         wait until each type is done prior to running the next type
         :param wait_time_between_test_types: if is_wait_between_test_types, the time to wait
 
         :return: test case paths object
-
         """
 
         if test_case_path.is_test_case:
